==> phpgroupware-jp-0.9.16.003-pre1.tar.bz2: phpgroupware/calendar/inc/hook_home_day.inc.php <==
<?php
  /**************************************************************************\
  * phpGroupWare - Calendar                                                  *
  * http://www.phpgroupware.org                                              *
  * Based on Webcalendar by Craig Knudsen <cknudsen@radix.net>               *
  *          http://www.radix.net/~cknudsen                                  *
  * Written by Mark Peters <skeeter@phpgroupware.org>                        *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

  /* $Id: hook_home_day.inc.php,v 1.2.18.1 2004/09/26 09:29:35 kazuyan Exp $ */

	$d1 = strtolower(substr(PHPGW_APP_INC,0,3));
	if($d1 == 'htt' || $d1 == 'ftp' )
	{
		echo 'Failed attempt to break in via an old Security Hole!<br>'."\n";
		$GLOBALS['phpgw']->common->phpgw_exit();
	}
	unset($d1);

	if ($GLOBALS['phpgw_info']['user']['preferences']['common']['lang'] != 'ja')
		$dateformat = lang($GLOBALS['phpgw']->common->show_date($time,'F')).' '.$GLOBALS['g_day'].', '.$GLOBALS['g_year'];
	else
		$dateformat = '<b>'.$GLOBALS['g_year'].lang('year').lang($GLOBALS['phpgw']->common->show_date($time,'F')).$GLOBALS['g_day'].lang('day').'</b>';
	$GLOBALS['extra_data'] = $GLOBALS['css']."\n".'<td>'."\n".'<table border="0" cols="3" width="100%"><tr><td align="center" width="35%" valign="top">'
		. ExecMethod('calendar.uicalendar.mini_calendar',
			Array(
				'day'		=> $GLOBALS['g_day'],
				'month'	=> $GLOBALS['g_month'],
				'year'	=> $GLOBALS['g_year'],
				'link'	=> 'day'
			)
		).'</td><td align="center"><table border="0" width="100%" cellspacing="0" cellpadding="0">'
		. '<tr><td align="center">'.$dateformat
		.'</td></tr><tr><td bgcolor="'.$GLOBALS['phpgw_info']['theme']['bg_text']
		.'" valign="top">'.ExecMethod('calendar.uicalendar.print_day',
			Array(
				'year'	=> $GLOBALS['g_year'],
				'month'	=> $GLOBALS['g_month'],
				'day'		=> $GLOBALS['g_day']
			)
		).'</td></tr></table>'."\n".'</td>'."\n".'</tr>'."\n".'</table>'."\n".'</td>'."\n";
?>

==> phpgroupware-jp-0.9.16.012-pre1.tar.bz2: phpgroupware/calendar/inc/hook_home_day.inc.php <==
<?php
  /**************************************************************************\
  * phpGroupWare - Calendar                                                  *
  * http://www.phpgroupware.org                                              *
  * Based on Webcalendar by Craig Knudsen <cknudsen@radix.net>               *
  *          http://www.radix.net/~cknudsen                                  *
  * Written by Mark Peters <skeeter@phpgroupware.org>                        *
  * --------------------------------------------                             *
  *  This program is free software; you can redistribute it and/or modify it *
  *  under the terms of the GNU General Public License as published by the   *
  *  Free Software Foundation; either version 2 of the License, or (at your  *
  *  option) any later version.                                              *
  \**************************************************************************/

  /* $Id: hook_home_day.inc.php,v 1.3.18.1 2007/09/14 02:02:21 kazuyan Exp $ */

	$d1 = strtolower(substr(PHPGW_APP_INC,0,3));
	if($d1 == 'htt' || $d1 == 'ftp' )
	{
		echo 'Failed attempt to break in via an old Security Hole!<br />'."\n";
		$GLOBALS['phpgw']->common->phpgw_exit();
	}
	unset($d1);

	if ($GLOBALS['phpgw_info']['user']['preferences']['common']['lang'] != 'ja')
		$dateformat = lang($GLOBALS['phpgw']->common->show_date($time,'F')).' '.$GLOBALS['g_day'].', '.$GLOBALS['g_year'];
	else
		$dateformat = '<b>'.$GLOBALS['g_year'].lang('year').lang($GLOBALS['phpgw']->common->show_date($time,'F')).$GLOBALS['g_day'].lang('day').'</b>';
	$GLOBALS['extra_data'] = $GLOBALS['css']."\n".'<td>'."\n".'<table border="0" cols="3" width="100%"><tr><td align="center" width="35%" valign="top">'
		. ExecMethod('calendar.uicalendar.mini_calendar',
			Array(
				'day'		=> $GLOBALS['g_day'],
				'month'	=> $GLOBALS['g_month'],
				'year'	=> $GLOBALS['g_year'],
				'link'	=> 'day'
			)
		).'</td><td align="center"><table border="0" width="100%" cellspacing="0" cellpadding="0">'
		. '<tr><td align="center">'.$dateformat
		.'</td></tr><tr><td bgcolor="'.$GLOBALS['phpgw_info']['theme']['bg_text']
		.'" valign="top">'.ExecMethod('calendar.uicalendar.print_day',
			Array(
				'year'	=> $GLOBALS['g_year'],
				'month'	=> $GLOBALS['g_month'],
				'day'		=> $GLOBALS['g_day']
			)
		).'</td></tr></table>'."\n".'</td>'."\n".'</tr>'."\n".'</table>'."\n".'</td>'."\n";
?>
